.. _cli:

Command-line tool
=================

.. contents::
   :local:

.. click:: clophfit.__main__:clop
   :prog: clop
   :nested: full

.. click:: clophfit.__main__:fit_titration
   :prog: fit-titration
   :nested: full

.. click:: clophfit.__main__:ppr
   :prog: ppr
   :nested: full

.. click:: clophfit.__main__:note2csv
   :prog: note_to_csv
   :nested: full
